@@ -40,7 +40,7 @@ rt IdlExpr::fn() { \
 // Error functions
 
 EXPR_ERR(IdlLongVal, evalAsLongV, "an integer", IdlLongVal((IDL_ULong)1))
-#ifdef HAS_LongLong
+#ifdef OMNI_HAS_LongLong
 EXPR_ERR(IdlLongLongVal, evalAsLongLongV, "an integer",
          IdlLongLongVal((IDL_ULongLong)1))
 #endif
@@ -50,7 +50,7 @@ EXPR_ERR(IDL_Double,       evalAsDouble,     "a double",              1.0)
 EXPR_ERR(IDL_Boolean,      evalAsBoolean,    "a boolean",             0)
 EXPR_ERR(IDL_Char,         evalAsChar,       "a character",           '!')
 EXPR_ERR(const char*,      evalAsString,     "a string",              "!")
-#ifdef HAS_LongDouble
+#ifdef OMNI_HAS_LongDouble
 EXPR_ERR(IDL_LongDouble,   evalAsLongDouble, "a long double",         1.0)
 #endif
 EXPR_ERR(IDL_WChar,        evalAsWChar,      "a wide character",      '!')
@@ -127,7 +127,7 @@ IDL_Octet IdlExpr::evalAsOctet()
   }
   return v.u;
 }
-#ifdef HAS_LongLong
+#ifdef OMNI_HAS_LongLong
 IDL_LongLong IdlExpr::evalAsLongLong()
 {
   IdlLongLongVal v = evalAsLongLongV();
@@ -184,7 +184,7 @@ const IDL_WChar* DummyExpr::evalAsWString() { return EMPTY_WSTRING; }
 // Literals
 
 IdlLongVal IntegerExpr::evalAsLongV() {
-#ifdef HAS_LongLong
+#ifdef OMNI_HAS_LongLong
   if (value_ > 0xffffffff) {
     IdlError(file(), line(), "Integer literal is too large for unsigned long");
     return IdlLongVal((IDL_ULong)1);
@@ -192,7 +192,7 @@ IdlLongVal IntegerExpr::evalAsLongV() {
 #endif
   return IdlLongVal((IDL_ULong)value_);
 }
-#ifdef HAS_LongLong
+#ifdef OMNI_HAS_LongLong
 IdlLongLongVal IntegerExpr::evalAsLongLongV() {
   return IdlLongLongVal((IDL_ULongLong)value_);
 }
@@ -235,7 +235,7 @@ IDL_Float FloatExpr::evalAsFloat() {
 }
 IDL_Double FloatExpr::evalAsDouble() {
   IDL_Double   f = value_;
-#ifdef HAS_LongDouble
+#ifdef OMNI_HAS_LongDouble
   IdlFloatLiteral g = f;
   if (f != g)
     IdlWarning(file(), line(), "Loss of precision converting literal "
@@ -243,7 +243,7 @@ IDL_Double FloatExpr::evalAsDouble() {
 #endif
   return f;
 }
-#ifdef HAS_LongDouble
+#ifdef OMNI_HAS_LongDouble
 IDL_LongDouble FloatExpr::evalAsLongDouble() {
   return value_;
 }
@@ -284,7 +284,7 @@ IdlLongVal ConstExpr::evalAsLongV() {
   case IdlType::tk_ulong:  return IdlLongVal(IDL_ULong(c_->constAsULong()));
   case IdlType::tk_octet:  return IdlLongVal(IDL_ULong(c_->constAsOctet()));
 
-#ifdef HAS_LongLong
+#ifdef OMNI_HAS_LongLong
   case IdlType::tk_longlong:
     {
       IDL_LongLong v = c_->constAsLongLong();
@@ -320,7 +320,7 @@ IdlLongVal ConstExpr::evalAsLongV() {
   return IdlLongVal(IDL_ULong(1));
 }
 
-#ifdef HAS_LongLong
+#ifdef OMNI_HAS_LongLong
 
 IdlLongLongVal ConstExpr::evalAsLongLongV() {
   switch (c_->constKind()) {
@@ -357,7 +357,7 @@ IdlLongLongVal ConstExpr::evalAsLongLongV() {
     }
   }
 }
-#endif // HAS_LongLong
+#endif // OMNI_HAS_LongLong
 
 
 IDL_Float ConstExpr::evalAsFloat() {
@@ -370,7 +370,7 @@ IDL_Float ConstExpr::evalAsFloat() {
 #else
   case IdlType::tk_double:     r = (float)(double)c_->constAsDouble(); break;
 #endif
-#ifdef HAS_LongDouble
+#ifdef OMNI_HAS_LongDouble
   case IdlType::tk_longdouble: r = c_->constAsLongDouble(); break;
 #endif
   default:
@@ -399,7 +399,7 @@ IDL_Double ConstExpr::evalAsDouble() {
   case IdlType::tk_float:      r = (double)(float)c_->constAsFloat(); break;
 #endif
   case IdlType::tk_double:     r = c_->constAsDouble();     break;
-#ifdef HAS_LongDouble
+#ifdef OMNI_HAS_LongDouble
   case IdlType::tk_longdouble: r = c_->constAsLongDouble(); break;
 #endif
   default:
@@ -418,7 +418,7 @@ IDL_Double ConstExpr::evalAsDouble() {
   return r;
 }
 
-#ifdef HAS_LongDouble
+#ifdef OMNI_HAS_LongDouble
 IDL_LongDouble ConstExpr::evalAsLongDouble() {
   IDL_LongDouble r;
 
@@ -443,7 +443,7 @@ IDL_LongDouble ConstExpr::evalAsLongDouble() {
   }
   return r;
 }
-#endif // HAS_LongDouble
+#endif // OMNI_HAS_LongDouble
 
 
 #define CONST_EXPR_EVAL(rt, eop, tk, cop, str, rv) \
@@ -513,7 +513,7 @@ IdlLongVal OrExpr::evalAsLongV() {
   else
     return IdlLongVal(IDL_ULong(a.u | b.u));
 }
-#ifdef HAS_LongLong
+#ifdef OMNI_HAS_LongLong
 IdlLongLongVal OrExpr::evalAsLongLongV() {
   IdlLongLongVal a = a_->evalAsLongLongV();
   IdlLongLongVal b = b_->evalAsLongLongV();
@@ -535,7 +535,7 @@ IdlLongVal XorExpr::evalAsLongV() {
   else
     return IdlLongVal(IDL_ULong(a.u ^ b.u));
 }
-#ifdef HAS_LongLong
+#ifdef OMNI_HAS_LongLong
 IdlLongLongVal XorExpr::evalAsLongLongV() {
   IdlLongLongVal a = a_->evalAsLongLongV();
   IdlLongLongVal b = b_->evalAsLongLongV();
@@ -557,7 +557,7 @@ IdlLongVal AndExpr::evalAsLongV() {
   else
     return IdlLongVal(IDL_ULong(a.u & b.u));
 }
-#ifdef HAS_LongLong
+#ifdef OMNI_HAS_LongLong
 IdlLongLongVal AndExpr::evalAsLongLongV() {
   IdlLongLongVal a = a_->evalAsLongLongV();
   IdlLongLongVal b = b_->evalAsLongLongV();
@@ -587,7 +587,7 @@ IdlLongVal RShiftExpr::evalAsLongV() {
   else
     return IdlLongVal(IDL_ULong(a.u >> b.u));
 }
-#ifdef HAS_LongLong
+#ifdef OMNI_HAS_LongLong
 IdlLongLongVal RShiftExpr::evalAsLongLongV() {
   IdlLongLongVal a = a_->evalAsLongLongV();
   IdlLongLongVal b = b_->evalAsLongLongV();
@@ -619,7 +619,7 @@ IdlLongVal LShiftExpr::evalAsLongV() {
   else
     return IdlLongVal(IDL_ULong(a.u << b.u));
 }
-#ifdef HAS_LongLong
+#ifdef OMNI_HAS_LongLong
 IdlLongLongVal LShiftExpr::evalAsLongLongV() {
   IdlLongLongVal a = a_->evalAsLongLongV();
   IdlLongLongVal b = b_->evalAsLongLongV();
@@ -658,7 +658,7 @@ IdlLongVal ModExpr::evalAsLongV() {
   }
   return IdlLongVal(IDL_ULong(0)); // Never reach here
 }
-#ifdef HAS_LongLong
+#ifdef OMNI_HAS_LongLong
 IdlLongLongVal ModExpr::evalAsLongLongV() {
   IdlLongLongVal a = a_->evalAsLongLongV();
   IdlLongLongVal b = b_->evalAsLongLongV();
@@ -720,7 +720,7 @@ IdlLongVal AddExpr::evalAsLongV() {
   return a;
 }
 
-#ifdef HAS_LongLong
+#ifdef OMNI_HAS_LongLong
 IdlLongLongVal AddExpr::evalAsLongLongV() {
   IdlLongLongVal a = a_->evalAsLongLongV();
   IdlLongLongVal b = b_->evalAsLongLongV();
@@ -772,7 +772,7 @@ ret AddExpr::op() { \
 }
 ADD_EXPR_EVAL_F(IDL_Float,      evalAsFloat,      "float")
 ADD_EXPR_EVAL_F(IDL_Double,     evalAsDouble,     "double")
-#ifdef HAS_LongDouble
+#ifdef OMNI_HAS_LongDouble
 ADD_EXPR_EVAL_F(IDL_LongDouble, evalAsLongDouble, "long double")
 #endif
 
@@ -827,7 +827,7 @@ IdlLongVal SubExpr::evalAsLongV() {
   return a;
 }
 
-#ifdef HAS_LongLong
+#ifdef OMNI_HAS_LongLong
 IdlLongLongVal SubExpr::evalAsLongLongV() {
   IdlLongLongVal a = a_->evalAsLongLongV();
   IdlLongLongVal b = b_->evalAsLongLongV();
@@ -879,7 +879,7 @@ ret SubExpr::op() { \
 }
 SUB_EXPR_EVAL_F(IDL_Float,      evalAsFloat,      "float")
 SUB_EXPR_EVAL_F(IDL_Double,     evalAsDouble,     "double")
-#ifdef HAS_LongDouble
+#ifdef OMNI_HAS_LongDouble
 SUB_EXPR_EVAL_F(IDL_LongDouble, evalAsLongDouble, "long double")
 #endif
 
@@ -935,7 +935,7 @@ IdlLongVal MultExpr::evalAsLongV() {
   return a;
 }
 
-#ifdef HAS_LongLong
+#ifdef OMNI_HAS_LongLong
 IdlLongLongVal MultExpr::evalAsLongLongV() {
   IdlLongLongVal a = a_->evalAsLongLongV();
   IdlLongLongVal b = b_->evalAsLongLongV();
@@ -987,7 +987,7 @@ ret MultExpr::op() { \
 }
 MULT_EXPR_EVAL_F(IDL_Float,      evalAsFloat,      "float")
 MULT_EXPR_EVAL_F(IDL_Double,     evalAsDouble,     "double")
-#ifdef HAS_LongDouble
+#ifdef OMNI_HAS_LongDouble
 MULT_EXPR_EVAL_F(IDL_LongDouble, evalAsLongDouble, "long double")
 #endif
 
@@ -1042,7 +1042,7 @@ IdlLongVal DivExpr::evalAsLongV() {
   return a;
 }
 
-#ifdef HAS_LongLong
+#ifdef OMNI_HAS_LongLong
 IdlLongLongVal DivExpr::evalAsLongLongV() {
   IdlLongLongVal a = a_->evalAsLongLongV();
   IdlLongLongVal b = b_->evalAsLongLongV();
@@ -1098,7 +1098,7 @@ ret DivExpr::op() { \
 }
 DIV_EXPR_EVAL_F(IDL_Float,      evalAsFloat,      "float")
 DIV_EXPR_EVAL_F(IDL_Double,     evalAsDouble,     "double")
-#ifdef HAS_LongDouble
+#ifdef OMNI_HAS_LongDouble
 DIV_EXPR_EVAL_F(IDL_LongDouble, evalAsLongDouble, "long double")
 #endif
 
@@ -1126,7 +1126,7 @@ IdlLongVal InvertExpr::evalAsLongV() {
   IdlLongVal e = e_->evalAsLongV();
   return IdlLongVal(~e.u);
 }
-#ifdef HAS_LongLong
+#ifdef OMNI_HAS_LongLong
 IdlLongLongVal InvertExpr::evalAsLongLongV() {
   IdlLongLongVal e = e_->evalAsLongLongV();
   return IdlLongLongVal(~e.u);
@@ -1147,7 +1147,7 @@ IdlLongVal MinusExpr::evalAsLongV() {
   }
 }
 
-#ifdef HAS_LongLong
+#ifdef OMNI_HAS_LongLong
 IdlLongLongVal MinusExpr::evalAsLongLongV() {
   IdlLongLongVal e = e_->evalAsLongLongV();
 
@@ -1167,7 +1167,7 @@ ret MinusExpr::op() { \
 }
 MINUS_EXPR_EVAL(IDL_Float,      evalAsFloat)
 MINUS_EXPR_EVAL(IDL_Double,     evalAsDouble)
-#ifdef HAS_LongDouble
+#ifdef OMNI_HAS_LongDouble
 MINUS_EXPR_EVAL(IDL_LongDouble, evalAsLongDouble)
 #endif
 
@@ -1184,12 +1184,12 @@ ret PlusExpr::op() { \
   return e_->op(); \
 }
 PLUS_EXPR_EVAL(IdlLongVal,     evalAsLongV)
-#ifdef HAS_LongLong
+#ifdef OMNI_HAS_LongLong
 PLUS_EXPR_EVAL(IdlLongLongVal, evalAsLongLongV)
 #endif
 PLUS_EXPR_EVAL(IDL_Float,      evalAsFloat)
 PLUS_EXPR_EVAL(IDL_Double,     evalAsDouble)
-#ifdef HAS_LongDouble
+#ifdef OMNI_HAS_LongDouble
 PLUS_EXPR_EVAL(IDL_LongDouble, evalAsLongDouble)
 #endif
 PLUS_EXPR_EVAL(IDL_Fixed*,     evalAsFixed)
